@@ -12,7 +12,7 @@
 #include <QStandardPaths>
 #include <QXmlStreamWriter>
 
-#include <kprocess.h>
+#include <KProcess>
 
 class MimeTypeWriterPrivate
 {
@@ -96,7 +96,7 @@ bool MimeTypeWriter::write()
     writer.writeStartElement(nsUri, QStringLiteral("glob-deleteall"));
     writer.writeEndElement(); // glob-deleteall
 
-    for (const QString &pattern : qAsConst(d->m_patterns)) {
+    for (const QString &pattern : std::as_const(d->m_patterns)) {
         writer.writeStartElement(nsUri, QStringLiteral("glob"));
         writer.writeAttribute(QStringLiteral("pattern"), pattern);
         writer.writeEndElement(); // glob
